powered by
Returns cards joined with notes, decks, and models for complete analysis.
anki_cards_full(path = NULL, profile = NULL)
A tibble with card data joined with note content, deck names, and model info
Path to collection.anki2 (auto-detected if NULL)
Profile name (first profile if NULL)
if (FALSE) { cards_full <- anki_cards_full() }
Run the code above in your browser using DataLab