Learn R Programming

ankiR (version 0.6.0)

anki_leeches: Find leech cards (high lapse count)

Description

Leeches are cards that you keep forgetting. By default, Anki marks cards as leeches after 8 lapses.

Usage

anki_leeches(path = NULL, profile = NULL, threshold = 8, include_notes = FALSE)

Value

A tibble of leech cards ordered by lapses

Arguments

path

Path to collection.anki2 (auto-detected if NULL)

profile

Profile name (first profile if NULL)

threshold

Minimum number of lapses to consider a leech (default 8)

include_notes

If TRUE, join with note data

Examples

Run this code
if (FALSE) {
leeches <- anki_leeches()
leeches <- anki_leeches(threshold = 5)
}

Run the code above in your browser using DataLab