powered by
Leeches are cards that you keep forgetting. By default, Anki marks cards as leeches after 8 lapses.
anki_leeches(path = NULL, profile = NULL, threshold = 8, include_notes = FALSE)
A tibble of leech cards ordered by lapses
Path to collection.anki2 (auto-detected if NULL)
Profile name (first profile if NULL)
Minimum number of lapses to consider a leech (default 8)
If TRUE, join with note data
if (FALSE) { leeches <- anki_leeches() leeches <- anki_leeches(threshold = 5) }
Run the code above in your browser using DataLab